from typing import Any, Optional

class UserAgentParser:
    platforms: Any
    browsers: Any
    def __init__(self): ...
    def __call__(self, user_agent): ...

class UserAgent:
    string: Any
    platform: Optional[str]
    browser: Optional[str]
    version: Optional[str]
    language: Optional[str]
    def __init__(self, environ_or_string): ...
    def to_header(self): ...
    def __nonzero__(self): ...
    __bool__: Any



from typing import Any, Callable, Optional, Type, TypeVar, overload

_F = TypeVar("_F", bound=Callable[..., Any])

class ClassicAdapter:
    reason: str
    version: str
    action: Optional[str]
    category: Type[DeprecationWarning]
    def __init__(
        self, reason: str = ..., version: str = ..., action: Optional[str] = ..., category: Type[DeprecationWarning] = ...
    ) -> None: ...
    def get_deprecated_msg(self, wrapped: Callable[..., Any], instance: object) -> str: ...
    def __call__(self, wrapped: _F) -> Callable[[_F], _F]: ...

@overload
def deprecated(__wrapped: _F) -> _F: ...
@overload
def deprecated(
    reason: str = ..., *, version: str = ..., action: Optional[str] = ..., category: Optional[Type[DeprecationWarning]] = ...
) -> Callable[[_F], _F]: ...
